@@ -13,9 +13,26 @@
 #'   \item UHT: Unsuitable due to high temperature 
 #' }
 #' 
-#' @import ggplot2
-#' @importFrom tidyr gather
-#' @importFrom stats na.omit
+#' @importFrom ggplot2 
+#'   ggplot
+#'   aes
+#'   geom_raster
+#'   coord_fixed
+#'   scale_fill_manual
+#'   theme
+#'   facet_wrap
+#'   guides
+#'   guide_legend
+#'   element_text
+#'   element_blank
+#'   labs
+#'   unit
+#' 
+#' @importFrom tidyr 
+#'   gather
+#' 
+#' @importFrom terra 
+#'   na.omit
 #' @param zoning A stack generated in ccrop_zoning
 #' @examples 
 #' ### Data preparation
@@ -28,11 +45,13 @@
 #' @export
 
 
-
 plot_ccrop_zoning<-function(zoning){
   
+xy<-terra::crds(zoning)
+
+df <- as.data.frame(terra::as.points(zoning))
+df<- cbind(xy, df)
 
-df <- as.data.frame(rasterToPoints(zoning))
 for(i in 3:14){
   df[,i] <- factor(df[,i],levels=c(1,2,3, 4, 5),
                    labels=c("ST", "RLT", "RHT","ULT",
@@ -40,7 +59,7 @@ for(i in 3:14){
 }
 
 
-df<-na.omit(gather(df, "Months", "climatic zoning", 3:14))
+df<-terra::na.omit(tidyr::gather(df, "Months", "climatic zoning", 3:14))
 Name.months<-c( "January", "February", "March", "April", "May", "June",
                 "July", "August", "September", "October", "November", "December")
 levels(df$Months)<-Name.months
@@ -50,10 +69,10 @@ cbbPalette <- c("ST" = "#009E73", "RLT" = "#56B4E9",
                 "RHT" = "#F0E442", "ULT" = "#000000",
                 "UHT" = "#E69F00")# SAT = Suitable air temperature;
 
-unique(df$Months)
-ggplot(data=df, aes(y = df$y, x = df$x)) +
+
+ggplot2::ggplot(data=df, aes(y = df$y, x = df$x)) +
   geom_raster(aes(fill= df$`climatic zoning`))+
-  coord_fixed(xlim = c(extent(zoning)[1], extent(zoning)[2]))+
+  coord_fixed(xlim = c(terra::ext(zoning)[1], terra::ext(zoning)[2]))+
   scale_fill_manual(values = cbbPalette) +
   theme(axis.title.x = element_blank(),
         axis.title.y = element_blank(),
@@ -70,4 +89,3 @@ ggplot(data=df, aes(y = df$y, x = df$x)) +
   labs(fill = "Climatic zoning:")
 }
 
-
